==================================================
scikit-spectra: Tools for explorative spectroscopy
==================================================

**Official Documentation** hosted at `http://hugadams.github.io/scikit-spectra/`

Support
=======

Questions?  Message: skspec@googlegroups.com

License
=======

3-Clause Revised BSD_

   .. _BSD : https://github.com/hugadams/scikit-spectra/blob/master/LICENSE.txt


